@@ -15,8 +15,8 @@ sub handle_request {
     my $client_id     = $req->param("client_id");
     my $client_secret = $req->param("client_secret");
 
-    my $user_id = $dh->get_client_user_id($client_id, $client_secret)
-        or OAuth::Lite2::Server::Error::InvalidClient->throw;
+    my $user_id = $dh->get_client_user_id($client_id, $client_secret);
+    OAuth::Lite2::Server::Error::InvalidClient->throw unless defined $user_id;
 
     my $scope = $req->param("scope");
 
